#region License
// Copyright (c) 2007 James Newton-King
//
// Permission is hereby granted, free of charge, to any person
// obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without
// restriction, including without limitation the rights to use,
// copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following
// conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
// OTHER DEALINGS IN THE SOFTWARE.
#endregion

using System;
using System.Collections.Generic;
using System.Text;
using NUnit.Framework;
using Utilities.Miscellaneous;
using Utilities.Converters;
using System.Net.Mail;
using Utilities.Email;
using Utilities.Testing;

namespace Utilities.Test.Converters
{
  public class MailAddressCollectionTypeConverterFixture : TestFixtureBase
  {
    [Test]
    public void ConvertFromString()
    {
      MailAddressCollectionTypeConverter c = new MailAddressCollectionTypeConverter();
      Assert.IsTrue(c.CanConvertFrom(typeof(string)));

      MailAddressCollection a;

      a = (MailAddressCollection)c.ConvertFrom("james@test.com");
      Assert.AreEqual(1, a.Count);
      Assert.AreEqual("james@test.com", a[0].Address);

      a = (MailAddressCollection)c.ConvertFrom(@"""James"" <james@test.com>, ""Fred"" <fred@test.com>");
      Assert.AreEqual(2, a.Count);
      Assert.AreEqual("james@test.com", a[0].Address);
      Assert.AreEqual("James", a[0].DisplayName);
      Assert.AreEqual("fred@test.com", a[1].Address);
      Assert.AreEqual("Fred", a[1].DisplayName);
    }

    [Test]
    [ExpectedException(typeof(FormatException), ExpectedMessage = "Error parsing email addresses: pie")]
    public void ConvertFromInvalidString()
    {
      MailAddressCollectionTypeConverter c = new MailAddressCollectionTypeConverter();
      c.ConvertFrom("pie");
    }

    [Test]
    [ExpectedException(typeof(NotSupportedException), ExpectedMessage = "MailAddressCollectionTypeConverter cannot convert from (null).")]
    public void ConvertFromNull()
    {
      MailAddressCollectionTypeConverter c = new MailAddressCollectionTypeConverter();
      c.ConvertFrom(null);
    }

    [Test]
    public void ConvertToString()
    {
      MailAddressCollectionTypeConverter c = new MailAddressCollectionTypeConverter();
      Assert.IsTrue(c.CanConvertTo(typeof(string)));

      string s;

      s = (string)c.ConvertTo(EmailUtils.ParseEmailAddresses(@"""James"" <james@test.com>, ""Fred"" <fred@test.com>"), typeof(string));
      Assert.AreEqual(@"""James"" <james@test.com>, ""Fred"" <fred@test.com>", s);

      s = (string)c.ConvertTo(null, typeof(string));
      Assert.AreEqual(string.Empty, s);
    }
  }
}