#region License
// Copyright (c) 2007 James Newton-King
//
// Permission is hereby granted, free of charge, to any person
// obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without
// restriction, including without limitation the rights to use,
// copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following
// conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
// OTHER DEALINGS IN THE SOFTWARE.
#endregion

using System;
using System.Collections.Generic;
using System.Text;
using NUnit.Framework;
using Utilities.Miscellaneous;
using System.Globalization;
using System.Data.SqlTypes;
using System.IO;
using Utilities.Testing;
using Utilities.Web;
using System.Collections.Specialized;

namespace Utilities.Test.Web
{
  public class HttpValueCollectionFixture : TestFixtureBase
  {
    #region UrlParsing
    [Test]
    public void UrlParsing()
    {
      HttpValueCollection h;

      h = new HttpValueCollection("hl=en&q=.net&meta=", false, true, Encoding.UTF8);
      Assert.AreEqual(3, h.Count);
      Assert.AreEqual("en", h["hl"]);
      Assert.AreEqual(".net", h["q"]);
      Assert.AreEqual(string.Empty, h["meta"]);
      Assert.AreEqual("hl=en&q=.net&meta=", h.ToString());

      h = new HttpValueCollection();
      h.FillFromString("hl=en&q=.net&meta=");
      Assert.AreEqual(3, h.Count);
      Assert.AreEqual("en", h["hl"]);
      Assert.AreEqual(".net", h["q"]);
      Assert.AreEqual(string.Empty, h["meta"]);
      Assert.AreEqual("hl=en&q=.net&meta=", h.ToString());

      h = new HttpValueCollection("hl=en&meta=&s&s&q=.net");
      Assert.AreEqual(4, h.Count);
      Assert.AreEqual("en", h["hl"]);
      Assert.AreEqual(".net", h["q"]);
      Assert.AreEqual(string.Empty, h["meta"]);
      Assert.AreEqual("s,s", h[null]);
      Assert.AreEqual("hl=en&meta=&s&s&q=.net", h.ToString());

      h = new HttpValueCollection();
      h.FillFromString(null);
      Assert.AreEqual(0, h.Count);

      h = new HttpValueCollection();
      h.FillFromString(string.Empty);
      Assert.AreEqual(0, h.Count);
    }
    #endregion
  }
}